from setuptools import find_packages, setup

setup(
    name='wizata_demo_scripts',
    packages=find_packages(),
    version='0.0.1',
    description='Scripts to make Wizata demos.',
    author='aco',
    url='https://github.com/albertcdc/Wizata_demos'
)